
<p align="center">
  <img src="SoundHub.png" alt="SoundHub" style="display:block; margin:auto; transform: scale(1.0);" />
</p>

## SoundHub 🎵

AI Audio Framework 

## Installation

To install the project, use the following command:

```python
pip install soundhub
```

## License

This project is licensed under the [MIT license](./LICENSE).
